@@ -23,6 +23,7 @@ from os.path import join, split, splitext
 from pyccuracy.airspeed import Template
 
 from pyccuracy import Page, ActionBase
+from pyccuracy.actions import MetaActionBase
 from pyccuracy.common import Settings, Context, locate, Status
 from pyccuracy.story_runner import *
 from pyccuracy.parsers import FileParser, ActionNotFoundError
@@ -50,6 +51,12 @@ class PyccuracyCore(object):
         self.parser = parser or FileParser()
         self.runner = runner
         sys.path.insert(0, os.getcwd())
+        self.used_elements = {}
+
+    def got_element(self, page, element_key, resolved_key):
+        if page not in self.used_elements:
+            self.used_elements[page] = []
+        self.used_elements[page] = element_key
 
     def run_tests(self, context=None, fso=None, **kwargs):
         settings = Settings(kwargs)
@@ -78,17 +85,30 @@ class PyccuracyCore(object):
             else:
                 return None
 
+        if len(self.parser.used_actions) != len(ActionBase.all()):
+            unused_actions = []
+            for action in ActionBase.all():
+                if hasattr(action, '__builtin__') and action.__builtin__:
+                    continue
+                if action not in self.parser.used_actions:
+                    unused_actions.append(action.__name__)
+            if unused_actions:
+                self.print_unused_actions_warning(unused_actions)
+
         if not fixture.stories:
             results = Result(fixture)
             self.print_results(context.settings.default_culture, results)
             return results
 
         try:
+            Page.subscribe_to_got_element(self.got_element)
+
             #running the tests
             results = self.runner.run_stories(settings=context.settings,
                                                fixture=fixture,
                                                context=context)
 
+            self.print_unused_elements_warning()
             self.print_results(context.settings.default_culture, results)
 
             if context.settings.write_report and results:
@@ -110,10 +130,52 @@ class PyccuracyCore(object):
             self.print_results(context.settings.default_culture, results)
             return results
 
+    def print_unused_elements_warning(self):
+        unused_elements = []
+        
+        for page_class in Page.all():
+            page = page_class()
+            if hasattr(page, "register"):
+                page.register()
+            if not page in self.used_elements:
+                unused_elements.extend(page.registered_elements.keys())
+            else:
+                for element in page.registered_elements.keys():
+                    element_key = '[%s] %s' % \
+                                (page.__class__.__name__, element)
+                                
+                    if element not in self.used_elements.values() and \
+                                element_key not in unused_elements:
+                        unused_elements.append(element_key)
+
+        if unused_elements:
+            template = """${YELLOW}WARNING!
+    ------------
+    The following elements are registered but are never used: 
+
+      *%s
+    ------------
+    ${NORMAL}
+    """
+            ctrl = TerminalController()
+            print ctrl.render(template % "\n  *".join(unused_elements))
+
+    def print_unused_actions_warning(self, unused_actions):
+        template = """${YELLOW}WARNING!
+------------
+The following actions are never used: 
+
+  *%s
+------------
+${NORMAL}
+"""
+        ctrl = TerminalController()
+        print ctrl.render(template % "\n  *".join(unused_actions))
+
     def print_lxml_import_error(self):
         template = """${RED}REPORT ERROR
 ------------
-Sorry, but you need to install lxml (python-lxml in aptitude)
+Sorry, but you need to install lxml (python-lxml in aptitude or easy_install lxml)
 before using the report feature in pyccuracy.
 If you do not need a report use the -R=false parameter.
 ${NORMAL}
